@@ -1,22 +1,18 @@
 #!/usr/bin/env ruby
 
-$VERBOSE=true
+$VERBOSE = true
 
-$: << "../lib"
+$: << '../lib'
 
 require 'Qt'
 system('rbuic -o zipdialogui.rb zipdialogui.ui')
 require 'zipdialogui.rb'
 require 'zip'
 
-
-
 a = Qt::Application.new(ARGV)
 
 class ZipDialog < ZipDialogUI
-
-
-  def initialize()
+  def initialize
     super()
     connect(child('add_button'), SIGNAL('clicked()'),
             self, SLOT('add_files()'))
@@ -32,16 +28,14 @@ class ZipDialog < ZipDialogUI
     Zip::File.foreach(@zip_filename, &proc)
   end
 
-  def refresh()
-    lv = child("entry_list_view")
+  def refresh
+    lv = child('entry_list_view')
     lv.clear
-    each {
-      |e|
+    each do |e|
       lv.insert_item(Qt::ListViewItem.new(lv, e.name, e.size.to_s))
-    }
+    end
   end
 
-
   def load(zipfile)
     @zip_filename = zipfile
     refresh
@@ -49,13 +43,11 @@ class ZipDialog < ZipDialogUI
 
   def add_files
     l = Qt::FileDialog.getOpenFileNames(nil, nil, self)
-    zipfile {
-      |zf|
-      l.each {
-        |path|
+    zipfile do |zf|
+      l.each do |path|
         zf.add(File.basename(path), path)
-      }
-    }
+      end
+    end
     refresh
   end
 
@@ -63,7 +55,7 @@ class ZipDialog < ZipDialogUI
     selected_items = []
     unselected_items = []
     lv_item = entry_list_view.first_child
-    while (lv_item)
+    while lv_item
       if entry_list_view.is_selected(lv_item)
         selected_items << lv_item.text(0)
       else
@@ -77,18 +69,17 @@ class ZipDialog < ZipDialogUI
     puts "items.size = #{items.size}"
 
     d = Qt::FileDialog.get_existing_directory(nil, self)
-    if (!d)
-      puts "No directory chosen"
+    if !d
+      puts 'No directory chosen'
     else
       zipfile { |zf| items.each { |e| zf.extract(e, File.join(d, e)) } }
     end
-
   end
 
   slots 'add_files()', 'extract_files()'
 end
 
-if !ARGV[0]
+unless ARGV[0]
   puts "usage: #{$0} zipname"
   exit
 end
@@ -97,5 +88,5 @@ zd = ZipDialog.new
 zd.load(ARGV[0])
 
 a.mainWidget = zd
-zd.show()
-a.exec()
+zd.show
+a.exec
