@@ -6,7 +6,7 @@ class AbstractInputStreamTest < MiniTest::Test
 
   TEST_LINES = ["Hello world#{$/}",
                 "this is the second line#{$/}",
-                "this is the last line"]
+                'this is the last line']
   TEST_STRING = TEST_LINES.join
   class TestAbstractInputStream
     include ::Zip::IOExtras::AbstractInputStream
@@ -17,10 +17,10 @@ class AbstractInputStreamTest < MiniTest::Test
       @readPointer = 0
     end
 
-    def sysread(charsToRead, buf = nil)
-      retVal=@contents[@readPointer, charsToRead]
-      @readPointer+=charsToRead
-      return retVal
+    def sysread(charsToRead, _buf = nil)
+      retVal = @contents[@readPointer, charsToRead]
+      @readPointer += charsToRead
+      retVal
     end
 
     def produce_input
@@ -28,7 +28,7 @@ class AbstractInputStreamTest < MiniTest::Test
     end
 
     def input_finished?
-      @contents[@readPointer] == nil
+      @contents[@readPointer].nil?
     end
   end
 
@@ -48,44 +48,43 @@ class AbstractInputStreamTest < MiniTest::Test
     assert_equal(4, @io.lineno)
   end
 
-  def test_getsMultiCharSeperator
-    assert_equal("Hell", @io.gets("ll"))
-    assert_equal("o world#{$/}this is the second l", @io.gets("d l"))
+  def test_gets_multi_char_seperator
+    assert_equal('Hell', @io.gets('ll'))
+    assert_equal("o world#{$/}this is the second l", @io.gets('d l'))
   end
 
   LONG_LINES = [
-      'x'*48 + "\r\n",
-      'y'*49 + "\r\n",
-      'rest',
+    'x' * 48 + "\r\n",
+    'y' * 49 + "\r\n",
+    'rest'
   ]
 
-  def test_getsMulitCharSeperator_split
+  def test_gets_mulit_char_seperator_split
     io = TestAbstractInputStream.new(LONG_LINES.join)
     assert_equal(LONG_LINES[0], io.gets("\r\n"))
     assert_equal(LONG_LINES[1], io.gets("\r\n"))
     assert_equal(LONG_LINES[2], io.gets("\r\n"))
   end
 
-  def test_getsWithSepAndIndex
+  def test_gets_with_sep_and_index
     io = TestAbstractInputStream.new(LONG_LINES.join)
     assert_equal('x', io.gets("\r\n", 1))
-    assert_equal('x'*47 + "\r", io.gets("\r\n", 48))
+    assert_equal('x' * 47 + "\r", io.gets("\r\n", 48))
     assert_equal("\n", io.gets(nil, 1))
     assert_equal('yy', io.gets(nil, 2))
   end
 
-  def test_getsWithIndex
+  def test_gets_with_index
     assert_equal(TEST_LINES[0], @io.gets(100))
     assert_equal('this', @io.gets(4))
   end
 
   def test_each_line
-    lineNumber=0
-    @io.each_line {
-        |line|
+    lineNumber = 0
+    @io.each_line do |line|
       assert_equal(TEST_LINES[lineNumber], line)
-      lineNumber+=1
-    }
+      lineNumber += 1
+    end
   end
 
   def test_readlines
@@ -96,7 +95,7 @@ class AbstractInputStreamTest < MiniTest::Test
     test_gets
     begin
       @io.readline
-      fail "EOFError expected"
+      fail 'EOFError expected'
     rescue EOFError
     end
   end
